@@ -6,12 +6,12 @@
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2, or (at your option)
  * any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
@@ -28,14 +28,16 @@
 #include <arch_barrier.h>
 #include <libs/stringlib.h>
 #include <libs/mathlib.h>
+#include <generic_mmu.h>
+
 #include <cpu_inline_asm.h>
 #include <cpu_vcpu_sysregs.h>
 #include <cpu_vcpu_vfp.h>
+#include <cpu_vcpu_ptrauth.h>
 #include <cpu_vcpu_helper.h>
-
 #include <generic_timer.h>
 #include <arm_features.h>
-#include <mmu_lpae.h>
+#include <arch_cache.h>
 
 void cpu_vcpu_halt(struct vmm_vcpu *vcpu, arch_regs_t *regs)
 {
@@ -301,13 +303,18 @@ void cpu_vcpu_reg_write(struct vmm_vcpu *vcpu,
 
 int arch_guest_init(struct vmm_guest *guest)
 {
+	u32 pgtbl_attr;
+
 	if (!guest->reset_count) {
 		guest->arch_priv = vmm_malloc(sizeof(struct arm_guest_priv));
 		if (!guest->arch_priv) {
 			return VMM_ENOMEM;
 		}
 
-		arm_guest_priv(guest)->ttbl = mmu_lpae_ttbl_alloc(TTBL_STAGE2);
+		pgtbl_attr = MMU_ATTR_REMOTE_TLB_FLUSH;
+		pgtbl_attr |= MMU_ATTR_HW_TAG_VALID;
+		arm_guest_priv(guest)->ttbl = mmu_pgtbl_alloc(MMU_STAGE2, -1,
+						pgtbl_attr, guest->id);
 		if (!arm_guest_priv(guest)->ttbl) {
 			vmm_free(guest->arch_priv);
 			guest->arch_priv = NULL;
@@ -330,7 +337,7 @@ int arch_guest_deinit(struct vmm_guest *guest)
 	int rc;
 
 	if (guest->arch_priv) {
-		if ((rc = mmu_lpae_ttbl_free(arm_guest_priv(guest)->ttbl))) {
+		if ((rc = mmu_pgtbl_free(arm_guest_priv(guest)->ttbl))) {
 			return rc;
 		}
 		vmm_free(guest->arch_priv);
@@ -499,6 +506,7 @@ int arch_vcpu_init(struct vmm_vcpu *vcpu)
 			arm_set_feature(vcpu, ARM_FEATURE_DUMMY_C15_REGS);
 			arm_set_feature(vcpu, ARM_FEATURE_LPAE);
 			arm_set_feature(vcpu, ARM_FEATURE_TRUSTZONE);
+			arm_set_feature(vcpu, ARM_FEATURE_PTRAUTH);
 			break;
 		case ARM_CPUID_ARMV8:
 			arm_set_feature(vcpu, ARM_FEATURE_V8);
@@ -508,6 +516,7 @@ int arch_vcpu_init(struct vmm_vcpu *vcpu)
 			arm_set_feature(vcpu, ARM_FEATURE_ARM_DIV);
 			arm_set_feature(vcpu, ARM_FEATURE_LPAE);
 			arm_set_feature(vcpu, ARM_FEATURE_GENERIC_TIMER);
+			arm_set_feature(vcpu, ARM_FEATURE_PTRAUTH);
 			break;
 		default:
 			break;
@@ -599,6 +608,12 @@ int arch_vcpu_init(struct vmm_vcpu *vcpu)
 		goto fail_vfp_init;
 	}
 
+	/* Initialize PTRAUTH context */
+	rc = cpu_vcpu_ptrauth_init(vcpu);
+	if (rc) {
+		goto fail_ptrauth_init;
+	}
+
 	/* Initialize generic timer context */
 	if (arm_feature(vcpu, ARM_FEATURE_GENERIC_TIMER)) {
 		if (vmm_devtree_read_u32(vcpu->node,
@@ -624,6 +639,10 @@ int arch_vcpu_init(struct vmm_vcpu *vcpu)
 	goto done;
 
 fail_gentimer_init:
+	if (!vcpu->reset_count) {
+		cpu_vcpu_ptrauth_deinit(vcpu);
+	}
+fail_ptrauth_init:
 	if (!vcpu->reset_count) {
 		cpu_vcpu_vfp_deinit(vcpu);
 	}
@@ -674,6 +693,12 @@ int arch_vcpu_deinit(struct vmm_vcpu *vcpu)
 		}
 	}
 
+	/* Free PTRAUTH context */
+	rc = cpu_vcpu_ptrauth_deinit(vcpu);
+	if (rc) {
+		goto done;
+	}
+
 	/* Free VFP context */
 	rc = cpu_vcpu_vfp_deinit(vcpu);
 	if (rc) {
@@ -695,7 +720,7 @@ int arch_vcpu_deinit(struct vmm_vcpu *vcpu)
 done:
 	msr(cptr_el2, saved_cptr_el2);
 	msr(hstr_el2, saved_hstr_el2);
-	return VMM_OK;
+	return rc;
 }
 
 void arch_vcpu_switch(struct vmm_vcpu *tvcpu,
@@ -728,6 +753,8 @@ void arch_vcpu_switch(struct vmm_vcpu *tvcpu,
 			cpu_vcpu_sysregs_save(tvcpu);
 			/* Save VFP and SIMD context */
 			cpu_vcpu_vfp_save(tvcpu);
+			/* Save PTRAUTH context */
+			cpu_vcpu_ptrauth_save(tvcpu);
 			/* Save generic timer */
 			if (arm_feature(tvcpu, ARM_FEATURE_GENERIC_TIMER)) {
 				generic_timer_vcpu_context_save(tvcpu,
@@ -749,6 +776,8 @@ void arch_vcpu_switch(struct vmm_vcpu *tvcpu,
 			generic_timer_vcpu_context_restore(vcpu,
 						arm_gentimer_context(vcpu));
 		}
+		/* Restore PTRAUTH context */
+		cpu_vcpu_ptrauth_restore(vcpu);
 		/* Restore VFP and SIMD context */
 		cpu_vcpu_vfp_restore(vcpu);
 		/* Restore sysregs context */
@@ -762,8 +791,7 @@ void arch_vcpu_switch(struct vmm_vcpu *tvcpu,
 		msr(cptr_el2, arm_priv(vcpu)->cptr);
 		msr(hstr_el2, arm_priv(vcpu)->hstr);
 		/* Update hypervisor Stage2 MMU context */
-		mmu_lpae_stage2_chttbl(vcpu->guest->id,
-			       arm_guest_priv(vcpu->guest)->ttbl);
+		mmu_stage2_change_pgtbl(arm_guest_priv(vcpu->guest)->ttbl);
 		/* Flush TLB if moved to new host CPU */
 		if (arm_priv(vcpu)->last_hcpu != vmm_smp_processor_id()) {
 			/* Invalidate all guest TLB enteries because
@@ -858,6 +886,9 @@ void arch_vcpu_regs_dump(struct vmm_chardev *cdev, struct vmm_vcpu *vcpu)
 	/* Print VFP context */
 	cpu_vcpu_vfp_dump(cdev, vcpu);
 
+	/* Print PTRAUTH context */
+	cpu_vcpu_ptrauth_dump(cdev, vcpu);
+
 	/* Print sysregs context */
 	cpu_vcpu_sysregs_dump(cdev, vcpu);
 }
