@@ -41,8 +41,8 @@ BUILD_XVISOR_ONLY="no"
 BUILD_XVISOR_OUTPUT_PATH=`pwd`/build/xvisor
 BUILD_TARBALL_PATH=`pwd`/tarball
 BUILD_GUEST_OUTPUT_PATH=`pwd`/build/guest
-BUILD_LINUX_VERSION="5.4.6"
-BUILD_BUSYBOX_VERSION="1.31.1"
+BUILD_LINUX_VERSION="6.1.1"
+BUILD_BUSYBOX_VERSION="1.33.1"
 BUILD_PRINT_CONFIG_ONLY="no"
 
 # Derived options
@@ -138,29 +138,19 @@ fi
 
 case "${BUILD_RISCV_XLEN}" in
 32b)
-	BUILD_XVISOR_ARCH="riscv"
-	BUILD_XVISOR_CROSS_COMPILE_PREFERRED=riscv32-unknown-linux-gnu-
-	BUILD_LINUX_ARCH="riscv"
-	BUILD_LINUX_CROSS_COMPILE_PREFERRED=riscv32-unknown-linux-gnu-
-	BUILD_BUSYBOX_CROSS_COMPILE_PREFERRED=riscv32-unknown-linux-gnu-
 	;;
 64b)
-	BUILD_XVISOR_ARCH="riscv"
-	BUILD_XVISOR_CROSS_COMPILE_PREFERRED=riscv64-linux-
-	BUILD_LINUX_ARCH="riscv"
-	if [ "${BUILD_GUEST_TYPE}" == "virt32" ]; then
-		BUILD_LINUX_CROSS_COMPILE_PREFERRED=riscv32-unknown-linux-gnu-
-		BUILD_BUSYBOX_CROSS_COMPILE_PREFERRED=riscv32-unknown-linux-gnu-
-	else
-		BUILD_LINUX_CROSS_COMPILE_PREFERRED=riscv64-linux-
-		BUILD_BUSYBOX_CROSS_COMPILE_PREFERRED=riscv64-linux-
-	fi
 	;;
 *)
 	echo "Invalid RISC-V XLEN"
 	usage
 	;;
 esac
+BUILD_XVISOR_ARCH="riscv"
+BUILD_XVISOR_CROSS_COMPILE_PREFERRED=riscv64-unknown-linux-gnu-
+BUILD_LINUX_ARCH="riscv"
+BUILD_LINUX_CROSS_COMPILE_PREFERRED=riscv64-unknown-linux-gnu-
+BUILD_BUSYBOX_CROSS_COMPILE_PREFERRED=riscv64-unknown-linux-gnu-
 
 if [ -z "${BUILD_XVISOR_CROSS_COMPILE}" ]; then
 	BUILD_XVISOR_CROSS_COMPILE=${BUILD_XVISOR_CROSS_COMPILE_PREFERRED}
